==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/devcenter/kotlin/inputs/GetCatalogSyncErrorDetailsPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.devcenter.kotlin.inputs

import com.pulumi.azurenative.devcenter.inputs.GetCatalogSyncErrorDetailsPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property catalogName The name of the Catalog.
 * @property devCenterName The name of the devcenter.
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 */
public data class GetCatalogSyncErrorDetailsPlainArgs(
    public val catalogName: String,
    public val devCenterName: String,
    public val resourceGroupName: String,
) : ConvertibleToJava<com.pulumi.azurenative.devcenter.inputs.GetCatalogSyncErrorDetailsPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.devcenter.inputs.GetCatalogSyncErrorDetailsPlainArgs =
        com.pulumi.azurenative.devcenter.inputs.GetCatalogSyncErrorDetailsPlainArgs.builder()
            .catalogName(catalogName.let({ args0 -> args0 }))
            .devCenterName(devCenterName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetCatalogSyncErrorDetailsPlainArgs].
 */
@PulumiTagMarker
public class GetCatalogSyncErrorDetailsPlainArgsBuilder internal constructor() {
    private var catalogName: String? = null

    private var devCenterName: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value The name of the Catalog.
     */
    @JvmName("xrtsidmpnxpbuwkc")
    public suspend fun catalogName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.catalogName = mapped
    }

    /**
     * @param value The name of the devcenter.
     */
    @JvmName("undmumwpldpiuwqs")
    public suspend fun devCenterName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.devCenterName = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("mrrdyhohnpytpscw")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): GetCatalogSyncErrorDetailsPlainArgs = GetCatalogSyncErrorDetailsPlainArgs(
        catalogName = catalogName ?: throw PulumiNullFieldException("catalogName"),
        devCenterName = devCenterName ?: throw PulumiNullFieldException("devCenterName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/devcenter/kotlin/inputs/GetCatalogSyncErrorDetailsPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.devcenter.kotlin.inputs

import com.pulumi.azurenative.devcenter.inputs.GetCatalogSyncErrorDetailsPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property catalogName The name of the Catalog.
 * @property devCenterName The name of the devcenter.
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 */
public data class GetCatalogSyncErrorDetailsPlainArgs(
    public val catalogName: String,
    public val devCenterName: String,
    public val resourceGroupName: String,
) : ConvertibleToJava<com.pulumi.azurenative.devcenter.inputs.GetCatalogSyncErrorDetailsPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.devcenter.inputs.GetCatalogSyncErrorDetailsPlainArgs =
        com.pulumi.azurenative.devcenter.inputs.GetCatalogSyncErrorDetailsPlainArgs.builder()
            .catalogName(catalogName.let({ args0 -> args0 }))
            .devCenterName(devCenterName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetCatalogSyncErrorDetailsPlainArgs].
 */
@PulumiTagMarker
public class GetCatalogSyncErrorDetailsPlainArgsBuilder internal constructor() {
    private var catalogName: String? = null

    private var devCenterName: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value The name of the Catalog.
     */
    @JvmName("priwnwgessojrtqa")
    public suspend fun catalogName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.catalogName = mapped
    }

    /**
     * @param value The name of the devcenter.
     */
    @JvmName("dwxuthnakjjcneiw")
    public suspend fun devCenterName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.devCenterName = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("rcceycvyvfmfnpgh")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): GetCatalogSyncErrorDetailsPlainArgs = GetCatalogSyncErrorDetailsPlainArgs(
        catalogName = catalogName ?: throw PulumiNullFieldException("catalogName"),
        devCenterName = devCenterName ?: throw PulumiNullFieldException("devCenterName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
    )
}
